pub struct Arguments {
pub command: Commands,
pub client_config: Option<ClientConfig>,
}Expand description
A DHCPv4 client
Fields
command: CommandsThere is a command for each type of interaction a client would want to make with a server
client_config: Option<ClientConfig>These are global arguments that apply to all commands and not just a single one.