MessageOptionsList

Struct MessageOptionsList 

pub struct MessageOptionsList(/* private fields */);
A collection of MessageOptions.

Implementations

Source

impl MessageOptionsList

pub fn find_option(&self, tag: u8) -> Option<&MessageOptions>

Returns the MessageOptions that has the passed tag within the MessageOptionsList if it exists.

pub fn add_option(&mut self, option: MessageOptions)

Appends a MessageOptions onto the MessageOptionsList.

pub fn get(&self, index: usize) -> Option<&MessageOptions>

👎Deprecated

Returns the MessageOptions with the passed index in the list. WARNING: be careful using this as it might not always be available

pub fn set(&mut self, index: usize, option: MessageOptions)

👎Deprecated

Changes the MessageOptions at the passed index in the list. WARNING: be careful using this as it might not always be available

pub fn from_bytes(bytes: &[u8]) -> Self

Takes an array slice and parses the TLV sub-format