Socket

Struct Socket 

pub struct Socket { /* private fields */ }
A connection to a UdpSocket that understands how to send/receive Deliverable. Meant to be used by both Client and Server.

Currently wraps UdpSocket::bind

Implementations

Source

impl Socket

pub const EMPTY_MESSAGE_BUFFER: MessageBuffer

A MessageBuffer with all 0 bytes.

pub fn new(address: SocketAddrV4, interface: Option<&String>) -> Self

Bind to an ip address/port and require that broadcast is enabled on the socket.

Should be be called by both Server::new and Client::new, so this can be slower/panic since it is not in the listen_once hot path.

pub fn get_ip(&self) -> Ipv4Addr

Returns the ip address of the bound socket.

Can panic as typically called outside of listen_once hot path.

pub fn receive<D: Decodable<Output = D>>(&self) -> Result<(D, SocketAddr)>

Decodes received bytes into a “message” type that implements DecodeMessage and returns it and the source address.

pub fn receive_raw(&self) -> Result<(UndecodedMessage, SocketAddr)>

Returns received bytes directly without being decoded into a Deliverable, which allows you to partially decode them yourself later.

pub fn receive_mock(partial_message: &[u8]) -> UndecodedMessage

Fills an empty undecoded message with passed bytes. Used to mock receiving a specific UndecodedMessage in tests, etc.

pub fn unicast<E: Encodable>( &self, encodable: &E, address: SocketAddrV4, ) -> Result<()>

Converts a message to bytes and then sends it to the passed address.

pub fn broadcast<E: Encodable>(&self, encodable: &E, port: u16) -> Result<()>

Send a message as bytes to many devices on the local network.