LeaseConfig

Struct LeaseConfig 

pub struct LeaseConfig {
    pub leases_file_path: PathBuf,
    pub lease_time: LeaseTime,
    pub network_cidr: Ipv4Network,
    pub static_leases: HashMap<MacAddress, Ipv4Addr>,
    pub use_leases_file: bool,
}
All configuration for a Leases.

Fields

leases_file_path: PathBuf

The path where the leases files is written to and read from. The name, however, is always the same and not configurable.

This will only be used when the leases file is used.

lease_time: LeaseTime

See: LeaseTime

network_cidr: Ipv4Network

A range of IP addresses for the server to lease. Specified in CIDR notation. For example: 10.1.9.32/16

static_leases: HashMap<MacAddress, Ipv4Addr>

The server will always assign these ip adddresses to these mac addresses. All static leases must be within the network_cidr range.

use_leases_file: bool

Whether to read and write leases to a file to maintain state between server restarts. Defaults to true (when not in a benchmark or integration test) but you might want to set to false for performance, lack of storage, etc.