ServerConfig

Struct ServerConfig 

pub struct ServerConfig {
    pub path: PathBuf,
    pub server: InnerServerConfig,
    pub socket_config: SocketConfig,
    pub lease_config: LeaseConfig,
}
Representation of a toe-beans.toml file. Used by the Server.

This is exported for you to use in your application to generate a toe-beans.toml.

Fields

path: PathBuf

The path to a directory where this config will exist on disk.

server: InnerServerConfig

A subtable of configuration that is specific to, and used by, the Server.

socket_config: SocketConfig

A subtable of configuration that is specific to, and passed to, a Socket by both a Server and a Client.

lease_config: LeaseConfig

A subtable of configuration that is specific to, and passed to, a Leases by the Server.

Implementations

Source

impl ServerConfig

pub const FILE_NAME: &'static str = "toe-beans.toml"

The file name that the Config is read from and written to.

pub fn read(from_where: PathBuf) -> Self

Reads the toe-beans.toml file and deserializes it into a Config. Returns default options if there are any issues.

pub fn write(&self)

Serializes a Config and writes it to a toe-beans.toml file.