pub struct MessageOptionsList(/* private fields */);Expand description
A collection of MessageOptions.
Implementations
Sourceimpl MessageOptionsList
impl MessageOptionsList
Sourcepub fn find_option(&self, tag: u8) -> Option<&MessageOptions>
pub fn find_option(&self, tag: u8) -> Option<&MessageOptions>
Returns the MessageOptions that has the passed tag within the MessageOptionsList if it exists.
Sourcepub fn add_option(&mut self, option: MessageOptions)
pub fn add_option(&mut self, option: MessageOptions)
Appends a MessageOptions onto the MessageOptionsList.
Sourcepub fn get(&self, index: usize) -> Option<&MessageOptions>
👎Deprecated
pub fn get(&self, index: usize) -> Option<&MessageOptions>
Returns the MessageOptions with the passed index in the list.
WARNING: be careful using this as it might not always be available
Sourcepub fn set(&mut self, index: usize, option: MessageOptions)
👎Deprecated
pub fn set(&mut self, index: usize, option: MessageOptions)
Changes the MessageOptions at the passed index in the list.
WARNING: be careful using this as it might not always be available
Sourcepub fn from_bytes(bytes: &[u8]) -> Self
pub fn from_bytes(bytes: &[u8]) -> Self
Takes an array slice and parses the TLV sub-format