pub struct SocketConfig {
pub listen_address: SocketAddrV4,
pub interface: Option<String>,
}Expand description
All configuration for a Socket.
Fields
listen_address: SocketAddrV4The socket will bind to this address and port when calling Socket::new.
interface: Option<String>The name of the network interface to broadcast to. Currently only takes one interface.
Implementations
Sourceimpl SocketConfig
impl SocketConfig
Sourcepub fn default_server() -> Self
pub fn default_server() -> Self
Similar to a Default impl, but specifically for use with Server.
Uses the RESOLVED_SERVER_PORT.
Sourcepub fn default_client() -> Self
pub fn default_client() -> Self
Similar to a Default impl, but specifically for use with Client.
Uses the RESOLVED_CLIENT_PORT.