pub trait Encodable: EncodeMessage + Debug { }Expand description
A supertrait that defines everything a custom message needs to be encoded before being sent by a socket.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".