pub struct InnerServerConfig {
pub rapid_commit: bool,
pub server_address: Option<Ipv4Addr>,
pub parameters: HashMap<u8, MessageOptions>,
}Expand description
Configuration used specifically within a Server.
This differs from ServerConfig which bundles many configs, including:
’InnerServerConfig, SocketConfig, and LeasesConfig`.
Fields
rapid_commit: boolControls whether the server agrees to use Rapid Commit.
server_address: Option<Ipv4Addr>May or may not match the IP address in SocketConfig.listen_address.
For example, you might be listening to 0.0.0.0, but your server has another address it can be reached from.
This is used in both the siaddr field and ServerIdentifier option.
If None, then listen_address is used.
parameters: HashMap<u8, MessageOptions>DHCP option numbers (as a String) mapped to values that are used to respond to parameter request list options