pub struct ServerConfig {
pub path: PathBuf,
pub server: InnerServerConfig,
pub socket_config: SocketConfig,
pub lease_config: LeaseConfig,
}Expand description
Representation of a toe-beans.toml file. Used by the Server.
This is exported for you to use in your application to generate a toe-beans.toml.
Fields
path: PathBufThe path to a directory where this config will exist on disk.
server: InnerServerConfigA subtable of configuration that is specific to, and used by, the Server.
socket_config: SocketConfigA subtable of configuration that is specific to, and passed to, a Socket by both a Server and a Client.
lease_config: LeaseConfigA subtable of configuration that is specific to, and passed to, a Leases by the Server.
Implementations
Sourceimpl ServerConfig
impl ServerConfig